/***********************************************************************
    parallel.v - Parallel port replacement Verilog code

	Bill Rison, 2/9/12
************************************************************************/


module parallel (
/* PC104 bus pins */
	inout [7:0] pc_data,        // data to/from PC             
	input [9:0] address,        // PC address lines
	input ior, iow, aen, reset, // control lines from PC
	inout interrupt,            // Interrupt control line
	inout zws,                  // Zero wait state line
	
/* Parallel Port Pins */
	output [7:0] lpt_data,
	input  [7:3] lpt_status,
	output [3:0] lpt_control,

/* Pins reserved for other purposes */
	input sys_clock,            // 25 Mhz system clock          
	inout io_cs16,              // For 16-bit data transfers

    inout [7:0] HC11_data,
	input [11:0] sample_data, 
	input fifo1_ef,fifo1_hf,fifo1_ff,
	input fifo2_ef,fifo2_hf,fifo2_ff,
	input gps,
	input HC11_strb,
	input [3:0] time_select,
	input write_time,
	output [15:0] fifo_data,
	output fifo1_r,fifo1_w,fifo1_rst,
	output fifo2_r,fifo2_w,fifo2_rst,
	output fifo_oe,
	output HC11_stra,
	output HC11_reset,
	output test_pulse,
	output local_gps
);

`include "constants.v"

/* Wires out of PC Interface */
wire [7:0] pcint_pc_data_out;
wire pcint_board_select; 
wire pcint_pc_read; 
wire [7:0] pcint_data; 
wire [7:0] pcint_control; 



pcint pcint1 (
	.address      (address),
	.pc_data_in (pc_data),
	.ior (ior), .iow (iow), .aen (aen),
	.reset (reset),
	.status (lpt_status),

	.pc_data_out (pcint_pc_data_out),
	.data (pcint_data),
	.control (pcint_control),
	.pc_read (pcint_pc_read),
	.board_select (pcint_board_select),
);

assign pc_data =  pcint_pc_read ? 8'hzz : pcint_pc_data_out;  
assign zws = pcint_board_select ? 1'bz : 1'b0;
assign interrupt = pcint_control[4] ? lpt_status[7] : 1'bz;

assign lpt_data = pcint_data;
assign lpt_control[3] = ~pcint_control[3];
assign lpt_control[2] =  pcint_control[2];
assign lpt_control[1] = ~pcint_control[1];
assign lpt_control[0] = ~pcint_control[0];


/* Reserved outputs */
assign fifo1_w = 1'b1;
assign fifo1_rst = 1'b1;
assign fifo_data = 16'hffff;
assign HC11_stra = 1'b1;
assign local_gps = gps; 
assign fifo_oe = 1'b1;
assign fifo1_r = 1'b1;
assign fifo2_r = 1'b1;
assign HC11_reset = 1'h1;
assign fifo2_w = 1'b0;
assign fifo2_rst = 1'b1;
assign test_pulse = 1'b0;
assign HC11_data = 8'hzz;
assign io_cs16 = 1'bz;

endmodule
