module pcint(
  input [9:0] address,                        // PC 104 address 
  input [7:0] pc_data_in,                     // Data from PC 104 bus
  input ior, iow, aen, reset,                 // Control from PC 104 bus

  input [7:3] status,                         // Parallel port status lines

  output [7:0] pc_data_out,                   // Data to write to PC 104 bus
  output reg [7:0] data,                      // Parallel port data lines
  output reg [7:0] control,                   // Parallel port control lines
  output pc_read, board_select                // When to put data on PC 104 bus
);

`include "constants.v"

assign board_select = 
       (( (address[9:0] == STATUS_ADDR) ||
		  (address[9:0] == CONTROL_ADDR) ||
		  (address[9:0] == DATA_ADDR)) && (aen == 1'b0)) ? 
		  1'b0 : 1'b1;

assign pc_read = 
       (( (address[9:0] == STATUS_ADDR) ||
		  (address[9:0] == CONTROL_ADDR) ||
		  (address[9:0] == DATA_ADDR)) && (aen == 1'b0) && (ior == 1'b0)) ? 
		   1'b0 : 1'b1;


/* Write to data and control registers on rising edge of IOW */
always @(posedge reset or posedge iow) begin
	if (reset == 1'b1) begin
		data[7:0] <= 8'h00;
		control[7:0] <= 8'h00;
	end
	else begin
		if ((aen == 1'b0) && (address[9:0] == DATA_ADDR)) 
				data[7:0] <= pc_data_in[7:0];
		if ((aen == 1'b0) && (address[9:0] == CONTROL_ADDR)) 
 			control[7:0] <= pc_data_in[7:0];
		end
end

/* Read various registers by setting pc_data_out for appropriate addresses */
assign pc_data_out[7:0] = (address[9:0] == DATA_ADDR) ? data[7:0] :
                          (address[9:0] == CONTROL_ADDR) ? {3'b111,control[4:0]} :
                          (address[9:0] == STATUS_ADDR) ? {~status[7], status[6:3], 3'b111} :
						  DEFAULT_OUT;

endmodule

